==> ethnobotanyR_0.1.3.tar.gz: ethnobotanyR/inst/doc/ethnobotanyr_vignette.R <==
## ----setup, include = FALSE----------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

load("ethnobotanydata.rda")

## ---- echo= FALSE--------------------------------------------------------
knitr::kable(head(ethnobotanydata), digits = 2, caption = "First six rows of the example ethnobotany data included with ethnobotanyR")

## ------------------------------------------------------------------------
ethnobotanyR::URs(ethnobotanydata)

## ------------------------------------------------------------------------
ethnobotanyR::URsum(ethnobotanydata)

## ------------------------------------------------------------------------
ethnobotanyR::CIs(ethnobotanydata)

## ------------------------------------------------------------------------
ethnobotanyR::FCs(ethnobotanydata)

## ------------------------------------------------------------------------
ethnobotanyR::NUs(ethnobotanydata)

## ------------------------------------------------------------------------
ethnobotanyR::RFCs(ethnobotanydata)

## ------------------------------------------------------------------------
ethnobotanyR::RIs(ethnobotanydata)

## ------------------------------------------------------------------------
ethnobotanyR::UVs(ethnobotanydata)

## ---- fig.width=7, fig.height=7------------------------------------------
ethnobotanyR::ethnoChord(ethnobotanydata)

## ---- fig.width=7, fig.height=7------------------------------------------
ethnobotanyR::ethnoChordUser(ethnobotanydata)

==> ethnobotanyR_0.1.4.tar.gz: ethnobotanyR/inst/doc/ethnobotanyr_vignette.R <==
## ----setup, include = FALSE----------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

load("ethnobotanydata.rda")


## ---- echo= FALSE--------------------------------------------------------
knitr::kable(head(ethnobotanydata), digits = 2, caption = "First six rows of the example ethnobotany data included with ethnobotanyR")

## ------------------------------------------------------------------------
ethnobotanyR::URs(ethnobotanydata)

## ---- output_format = 'style="border:none"'------------------------------
ethnobotanyR::Radial_plot(ethnobotanydata, ethnobotanyR::URs)

## ------------------------------------------------------------------------
ethnobotanyR::URsum(ethnobotanydata)

## ------------------------------------------------------------------------
ethnobotanyR::Radial_plot(ethnobotanydata, ethnobotanyR::CIs)

## ------------------------------------------------------------------------
ethnobotanyR::Radial_plot(ethnobotanydata, ethnobotanyR::FCs)

## ------------------------------------------------------------------------
ethnobotanyR::Radial_plot(ethnobotanydata, ethnobotanyR::NUs)

## ------------------------------------------------------------------------
ethnobotanyR::Radial_plot(ethnobotanydata, ethnobotanyR::RFCs)

## ------------------------------------------------------------------------
ethnobotanyR::Radial_plot(ethnobotanydata, ethnobotanyR::RIs)

## ------------------------------------------------------------------------
ethnobotanyR::Radial_plot(ethnobotanydata, ethnobotanyR::UVs)

## ------------------------------------------------------------------------
ethnobotanyR::FLs(ethnobotanydata)

## ---- fig.width=7, fig.height=7------------------------------------------
ethnobotanyR::ethnoChord(ethnobotanydata)

## ---- fig.width=7, fig.height=7------------------------------------------
ethnobotanyR::ethnoChordUser(ethnobotanydata)
